@@ -917,9 +917,8 @@ class DocumentFamilyEndpoint(DocumentFamily, ClientEndpoint):
                 self.client)
             if mixin and mixin in updated_document_family.mixins:
                 return updated_document_family
-            if label and label in updated_document_family.labels:
+            if label and len(seq(updated_document_family.labels).filter(lambda l: l.name == label).to_list()) > 0:
                 return updated_document_family
-
             time.sleep(5)
 
         raise Exception(f"Not available on document family {self.id}")
@@ -1465,6 +1464,10 @@ def process_response(response) -> requests.Response:
             raise Exception(', '.join(messages))
 
         raise Exception("Bad request " + response.text)
+
+    if response.status_code != 200:
+        raise Exception(f"Unexpected status code ({response.status_code})")
+    
     return response
 
 
